@@ -1,4 +1,4 @@
-#' Plot GTFS object routes and their frequencies
+#' Plot GTFS stops and trips
 #'
 #' @param x a gtfs_obj as read by read_gtfs()
 #' @export
@@ -12,10 +12,10 @@
 #' nyc <- read_gtfs(local_gtfs_path)
 #' plot(nyc)
 #' }
-plot.gtfs <- function(x, ...) {
+plot.tidygtfs <- function(x, ...) {
   dots <- list(...)
   if(!feed_contains(x, "stops")) {
-    stop("Feed doesn't contain a stops table!")
+    stop("Feed doesn't contain a stops table")
   }
   x_stops <- x$stops 
   if(!"sf" %in% class(x$stops))  x_stops <- stops_as_sf(x$stops)
