@@ -1,4 +1,4 @@
-#' Convert stops and shapes to Simple Features#' 
+#' Convert stops and shapes to Simple Features
 #' 
 #' Stops are converted to POINT sf data frames. Shapes are created as
 #' LINESTRING data frame. Note that this function replaces stops and shapes
@@ -6,26 +6,29 @@
 #'
 #' @param gtfs_obj a standard tidytransit gtfs object
 #' @param skip_shapes if TRUE, shapes are not converted. Default FALSE.
+#' @param crs optional coordinate reference system (used by sf::st_transform) to transform 
+#'            lon/lat coordinates of stops and shapes
 #' @param quiet boolean whether to print status messages
 #' @return gtfs_obj a tidytransit gtfs object with stops and shapes as sf data frames
 #' @export
-gtfs_as_sf <- function(gtfs_obj, skip_shapes = FALSE, quiet = TRUE) {
+gtfs_as_sf <- function(gtfs_obj, skip_shapes = FALSE, crs = NULL, quiet = TRUE) {
   if(!quiet) message('Converting stops to simple features')
-  gtfs_obj$stops <- try(stops_as_sf(gtfs_obj$stops))
+  gtfs_obj$stops <- try(stops_as_sf(gtfs_obj$stops, crs))
   
   if(feed_contains(gtfs_obj, "shapes") && !skip_shapes) {
     if(!quiet) message('Converting shapes to simple features')
-    gtfs_obj$shapes <- try(shapes_as_sf(gtfs_obj$shapes))
+    gtfs_obj$shapes <- try(shapes_as_sf(gtfs_obj$shapes, crs))
   } else if(!skip_shapes) { 
     warning('No shapes available in gtfs_obj') 
   }
-  
   return(gtfs_obj)
 }
 
 #' Convert stops into Simple Features Points
 #'
 #' @param stops a gtfs$stops dataframe
+#' @param crs optional coordinate reference system (used by sf::st_transform) to transform 
+#'            lon/lat coordinates
 #' @return an sf dataframe for gtfs routes with a point column
 #' @export
 #' @examples
@@ -33,19 +36,25 @@ gtfs_as_sf <- function(gtfs_obj, skip_shapes = FALSE, quiet = TRUE) {
 #' some_stops <- gtfs_duke$stops[sample(nrow(gtfs_duke$stops), 40),]
 #' some_stops_sf <- stops_as_sf(some_stops)
 #' plot(some_stops_sf)
-stops_as_sf <- function(stops) {
+stops_as_sf <- function(stops, crs = NULL) {
   stops_sf <- sf::st_as_sf(stops,
                            coords = c("stop_lon", "stop_lat"),
                            crs = 4326)
+  if(!is.null(crs)) {
+    stops_sf <- sf::st_transform(stops_sf, crs)
+  }
+  
   return(stops_sf)
 }
 
 #' Convert shapes into Simple Features Linestrings
 #'
 #' @param gtfs_shapes a gtfs$shapes dataframe
+#' @param crs optional coordinate reference system (used by sf::st_transform) to transform 
+#'            lon/lat coordinates 
 #' @export
 #' @return an sf dataframe for gtfs shapes
-shapes_as_sf <- function(gtfs_shapes) {
+shapes_as_sf <- function(gtfs_shapes, crs = NULL) {
   list_of_line_tibbles <- split(gtfs_shapes, gtfs_shapes$shape_id)
   list_of_linestrings <- lapply(list_of_line_tibbles, shape_as_sf_linestring)
   
@@ -54,10 +63,14 @@ shapes_as_sf <- function(gtfs_shapes) {
   shapes_sf <- sf::st_sf(shape_id = names(list_of_line_tibbles), geometry = shape_linestrings)
   shapes_sf$shape_id <- as.character(shapes_sf$shape_id)
   
+  if(!is.null(crs)) {
+    shapes_sf <- sf::st_transform(shapes_sf, crs)
+  }
+  
   return(shapes_sf)
 }
 
-#' Get all trip shapes for a given route and service.
+#' Get all trip shapes for a given route and service
 #'
 #' @param gtfs_sf_obj tidytransit gtfs object with sf data frames
 #' @param route_ids routes to extract
@@ -100,7 +113,7 @@ get_route_geometry <- function(gtfs_sf_obj, route_ids = NULL, service_ids = NULL
   return(route_shapes)
 }
 
-#' Get all trip shapes for a given route and service.
+#' Get all trip shapes for given trip ids
 #'
 #' @param gtfs_sf_obj tidytransit gtfs object with sf data frames
 #' @param trip_ids trip_ids to extract shapes
